@@ -7,6 +7,7 @@ var CopyWebpackPlugin = require('copy-webpack-plugin')
 var url = require('url')
 var paths = require('./paths')
 var env = require('./env')
+var FlowBabelWebpackPlugin = require('flow-babel-webpack-plugin');
 
 // Assert this just to be safe.
 // Development builds of React are slow and not intended for production.
@@ -68,6 +69,7 @@ module.exports = {
       // Support React Native Web
       // https://www.smashingmagazine.com/2016/08/a-glimpse-into-the-future-with-react-native-for-web/
       'react-native': 'react-native-web',
+      'ovirtapi': './ovirtapi'
     },
   },
   // Resolve loaders (webpack plugins for CSS, images, transpilation) from the
@@ -239,6 +241,8 @@ module.exports = {
     }),
     // Note: this won't work without ExtractTextPlugin.extract(..) in `loaders`.
     new ExtractTextPlugin('static/css/[name].[contenthash:8].css'),
+
+    new FlowBabelWebpackPlugin(),
   ],
   // Some libraries import Node modules but don't use them in the browser.
   // Tell Webpack to provide empty mocks for them so importing them works.
